"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImsSessionUtils = void 0;
const imperative_1 = require("@zowe/imperative");
const Ims_constants_1 = require("../api/constants/Ims.constants");
const ImsSession_1 = require("../api/rest/ImsSession");
/**
 * Utility Methods for Zowe IMS plugin
 * @export
 */
class ImsSessionUtils {
    static createSessCfgFromArgs(args, doPrompting = true, handlerParams) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Creating a IMS session from arguments");
            const basePath = args.basePath; // ?? ImsConstants.BASE_PATH;
            // strip "/" before and after sessionBasePath
            // if (basePath.startsWith("/")) basePath = basePath.substring(1, basePath.length);
            // if (basePath.endsWith("/")) basePath = basePath.substring(0, basePath.length - 1);
            // if (!basePath.match(/ims\/api\/v1/))
            //   throw new ImperativeError({
            //     msg:
            //       "Make sure the base path value is: " + ImsConstants.BASE_PATH
            //   });
            const sessCfg = {
                hostname: args.host,
                port: args.port,
                rejectUnauthorized: args.rejectUnauthorized,
                basePath,
                protocol: (_b = (_a = args.protocol) === null || _a === void 0 ? void 0 : _a.toLowerCase()) !== null && _b !== void 0 ? _b : "https"
            };
            if (args.tokenType && args.tokenValue) {
                sessCfg.type = imperative_1.SessConstants.AUTH_TYPE_TOKEN;
                sessCfg.tokenType = args.tokenType;
                sessCfg.tokenValue = args.tokenValue;
            }
            else if (args.user && args.password) {
                sessCfg.user = args.user;
                sessCfg.password = args.password;
                sessCfg.type = imperative_1.SessConstants.AUTH_TYPE_BASIC;
            }
            const sessCfgWithCreds = yield imperative_1.ConnectionPropsForSessCfg.addPropsOrPrompt(sessCfg, args, { doPrompting, parms: handlerParams });
            return new ImsSession_1.ImsSession(Object.assign(Object.assign({}, sessCfgWithCreds), { imsConnectHost: args.imsConnectHost, imsConnectPort: args.imsConnectPort, plex: args.plex }));
        });
    }
    static getUrl(basePath) {
        return basePath === Ims_constants_1.ImsConstants.URL ? "" : Ims_constants_1.ImsConstants.URL;
    }
    /**
     * Given command line arguments, create a REST Client Session.
     * @static
     * @param {IProfile} args - The arguments specified by the user
     * @returns {Session} - A session for usage in the IMS REST Client
     */
    static createBasicImsSessionFromArguments(args) {
        this.log.debug("Creating a IMS session from arguments");
        return new ImsSession_1.ImsSession({
            type: args.password && args.user ? "basic" : "none",
            hostname: args.host,
            port: args.port,
            user: args.user,
            plex: args.plex,
            imsConnectHost: args.imsConnectHost,
            imsConnectPort: args.imsConnectPort,
            password: args.password,
            basePath: args.basePath,
            strictSSL: false,
            protocol: args.protocol ? args.protocol : "https"
        });
    }
    static get log() {
        return imperative_1.Logger.getAppLogger();
    }
}
exports.ImsSessionUtils = ImsSessionUtils;
ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP = "IMS Connection Options";
/**
 * Option used in profile creation and commands for hostname for IMS
 */
ImsSessionUtils.IMS_OPTION_HOST = {
    name: "host",
    aliases: ["H"],
    description: "The IMS Operations API server host name.",
    type: "string",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for port for IMS
 */
ImsSessionUtils.IMS_OPTION_PORT = {
    name: "port",
    aliases: ["P"],
    description: "The IMS Operations API server port.",
    type: "number",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for hostname for IMS
 */
ImsSessionUtils.IMS_OPTION_IMS_CONNECT_HOST = {
    name: "ims-connect-host",
    aliases: ["ich"],
    description: "The hostname of your instance of IMS Connect. This is typically the hostname " +
        "of the mainframe LPAR where IMS Connect is running.",
    type: "string",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for port for IMS
 */
ImsSessionUtils.IMS_OPTION_IMS_CONNECT_PORT = {
    name: "ims-connect-port",
    aliases: ["icp"],
    description: "The port of your instance of IMS Connect." +
        " This port can be found in your IMS Connect configuration file on the mainframe.",
    type: "number",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for port for IMS
 */
ImsSessionUtils.IMS_OPTION_PLEX = {
    name: "plex",
    aliases: ["x"],
    description: "The name of the IMS plex.",
    type: "string",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for username / ID  for IMS
 */
ImsSessionUtils.IMS_OPTION_USER = {
    name: "user",
    aliases: ["u"],
    description: "The web server user name where the IMS Operations API resides.",
    type: "string",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for password/passphrase for IMS
 */
ImsSessionUtils.IMS_OPTION_PASSWORD = {
    name: "password",
    aliases: ["pass"],
    description: "The web server user password where the IMS Operations API resides.",
    type: "string",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP,
};
/**
 * Option used in profile creation and commands for base path setting for connecting to z/OSMF
 */
ImsSessionUtils.IMS_OPTION_BASE_PATH = {
    name: "base-path",
    aliases: ["bp"],
    description: "The base path for your API mediation layer instance." +
        " Specify this option to prepend the base path to all z/OSMF resources when making REST requests." +
        " Do not specify this option if you are not using an API mediation layer.",
    type: "string",
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for protocol for CMCI
 */
ImsSessionUtils.IMS_OPTION_PROTOCOL = {
    name: "protocol",
    description: "Specifies protocol (http or https).",
    type: "string",
    defaultValue: "https",
    allowableValues: { values: ["http", "https"], caseSensitive: false },
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Option used in profile creation and commands for rejectUnauthorized setting for connecting to IMS
 */
ImsSessionUtils.IMS_OPTION_REJECT_UNAUTHORIZED = {
    name: "reject-unauthorized",
    aliases: ["ru"],
    description: "Reject self-signed certificates.",
    type: "boolean",
    defaultValue: true,
    group: ImsSessionUtils.IMS_CONNECTION_OPTION_GROUP
};
/**
 * Options related to connecting to IMS
 * These options can be filled in if the user creates a profile
 */
ImsSessionUtils.IMS_CONNECTION_OPTIONS = [
    ImsSessionUtils.IMS_OPTION_HOST,
    ImsSessionUtils.IMS_OPTION_PORT,
    ImsSessionUtils.IMS_OPTION_IMS_CONNECT_HOST,
    ImsSessionUtils.IMS_OPTION_IMS_CONNECT_PORT,
    ImsSessionUtils.IMS_OPTION_PLEX,
    ImsSessionUtils.IMS_OPTION_USER,
    ImsSessionUtils.IMS_OPTION_PASSWORD,
    ImsSessionUtils.IMS_OPTION_BASE_PATH,
    ImsSessionUtils.IMS_OPTION_PROTOCOL,
    ImsSessionUtils.IMS_OPTION_REJECT_UNAUTHORIZED
];
//# sourceMappingURL=ImsSessionUtils.js.map